@@ -1,3 +1,5 @@
+extern pam_module_t mod_pam_himmelblau;
+extern pam_module_t mod_pam_kanidm;
 extern pam_module_t mod_pam_access;
 extern pam_module_t mod_pam_apparmor;
 extern pam_module_t mod_pam_ccreds;
@@ -69,6 +71,8 @@ pam_module_t *common_module_list[] = {
   &mod_pam_fscrypt,
   &mod_pam_gnome_keyring,
   &mod_pam_group,
+  &mod_pam_himmelblau,
+  &mod_pam_kanidm,
   &mod_pam_krb5,
   &mod_pam_kwallet5,
   &mod_pam_lastlog2,
@@ -111,6 +115,8 @@ static pam_module_t *module_list_account[] = {
   &mod_pam_nam,
   &mod_pam_winbind,
   &mod_pam_time,
+  &mod_pam_himmelblau,
+  &mod_pam_kanidm,
   NULL
 };
 
@@ -136,6 +142,8 @@ static pam_module_t *module_list_auth[] = {
   &mod_pam_ldap,
   &mod_pam_nam,
   &mod_pam_winbind,
+  &mod_pam_himmelblau,
+  &mod_pam_kanidm,
                    /* Attention: if you add another module behind krb5
 					  you MUST change mod_pam_krb5.c */
   NULL
@@ -189,6 +197,8 @@ static pam_module_t *module_list_session[] = {
   &mod_pam_fscrypt,
   &mod_pam_env,
   &mod_pam_mktemp,
+  &mod_pam_himmelblau,
+  &mod_pam_kanidm,
   NULL
 };
 
